local tab = {}
tab.index = 150
tab.text = "All";
tab.value = "all";

tab.populate = function()
	
	local includeKeyless = KeystoneRollCall.db.global.allTabShowKeyless

	for i, keystone in pairs(KeystoneRollCall.db.global.keystones) do
		if keystone and keystone.name and keystone.level and keystone.level > 0 then
			local nameParts =  {strsplit("-",keystone.name or "")};			
			local dataRow = {
				keystone,
				KeystoneRollCall:colorFaction(nameParts[2],keystone.faction),
				KeystoneRollCall:colorClass(nameParts[1],keystone.class),
				KeystoneRollCall:colorClass(keystone.class,keystone.class),
				KeystoneRollCall:getIlvlLine(keystone),
				keystone.level == 0 and "" or ("+"..KeystoneRollCall:colorLevelDifficulty(keystone.level,keystone.level)),
				C_ChallengeMode.GetMapInfo(keystone.dungeon),
				KeystoneRollCall:getBestRunLine(keystone.bestLevel,keystone.bestDungeon)
			}
			if KeystoneRollCall:DoSearch(dataRow) then
				tinsert(KeystoneRollCall.tableData, dataRow);
			end
		end
	
	end
end

tab.setup = function(container)
	local cols = {{
			['name'] = '',
			['width'] = 1,
			["comparesort"] = function() end,
			['field'] = "name",
			['align'] = 'LEFT'
		},{
			['name'] = 'Realm',
			['width'] = 85,
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "realm",
		},{
			['name'] = 'Character',
			['width'] = 85,
			['align'] = 'LEFT', 
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "name"
		},{
			['name'] = 'Class',
			['width'] = 90,
			['align'] = 'LEFT', 
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "class",
		},{
			['name'] = 'ILvl',
			['width'] = 50,
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "equippedIlvl",
		},{
			['name'] = 'Level',
			['width'] = 40,
			['align'] = 'RIGHT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "level",
		},{
			['name'] = '  Dungeon',
			['width'] = 150,
			['align'] = 'LEFT',
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "dungeon",
		},{
			['name'] = "Best Run (This Week)",
			['width'] = 180,
			["comparesort"] = KeystoneRollCall.columnSort,
			['field'] = "bestLevel",
			['align'] = 'LEFT',
		}
	}
	
	KeystoneRollCall.tableData = {};
	KeystoneRollCall.dummyKeystones = {};
	KeystoneRollCall.scrollTable = KeystoneRollCall.ScrollingTable:CreateST(cols,24);
	KeystoneRollCall.scrollTable:SetData(KeystoneRollCall.tableData, true);
	
	KeystoneRollCall.scrollTable:RegisterEvents({
		['OnClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if not KeystoneRollCall.tableData or not KeystoneRollCall.tableData[realrow] then
				return
			end
			if KeystoneRollCall.tableData[realrow][1].dummy then
				SendChatMessage("If you get the addon Keystone Roll-Call we can easily view each other's keystones, as well as keystones from across our guilds.","WHISPER",  "Common", KeystoneRollCall.tableData[realrow][1].name);
			elseif KeystoneRollCall.tableData[realrow][1] then
				local keystone = KeystoneRollCall.tableData[realrow][1];
				if btn == "RightButton" then
					if UnitExists("target") and GetUnitName("target", true) then
						SendChatMessage(KeystoneRollCall:keystoneToString(keystone),"WHISPER", "COMMON",  GetUnitName("target", true));
					end
				else
					SendChatMessage(KeystoneRollCall:keystoneToString(keystone),KeystoneRollCall:getGroupChatChannel() ,  "Common")
				end
			
			end
		end,	
		['OnDoubleClick'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable, btn,...)
			if KeystoneRollCall.tableData and KeystoneRollCall.tableData[realrow] and not KeystoneRollCall.tableData[realrow][1].dummy then
				SendChatMessage(KeystoneRollCall:keystoneToString(KeystoneRollCall.tableData[realrow][1]),"GUILD" ,  "Common")
			end
		end,	
		['OnEnter'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			if not realrow or not KeystoneRollCall.tableData[realrow] then
				return
			end
			if not realrow or not KeystoneRollCall.tableData[realrow] then
				return
			end
			
			local key = KeystoneRollCall.tableData[realrow][1]
			
			if key.dummy then
				KeystoneRollCall.frame:SetStatusText("Click: Suggest Addon")
			else
				KeystoneRollCall.frame:SetStatusText("Left Click: Send to Party   -   Double Click: Send to Guild   -   Right Click: Send to Target")
			end
			
			KeystoneRollCall:showTooltip(key.name,rowFrame)
		end,
		['OnLeave'] = function(rowFrame, cellFrame, data, cols, row, realrow, column, scrollingTable,...)
			KeystoneRollCall.frame:SetStatusText("")
			if GameTooltip.bg then
				GameTooltip.bg:Hide()
			end
			GameTooltip:Hide()
		end,
	});
	
	local tableWrapper = KeystoneRollCall.AceGUI:Create('lib-st'):WrapST(KeystoneRollCall.scrollTable);
	tableWrapper.head_offset = 15;
	container:AddChild(tableWrapper);
end
KeystoneRollCall.tabs[tab.value] = tab;